@@ -205,7 +205,7 @@ class ModifiableFormat:
     self.__format = to
 
 class BaseForecast(ModifiableFormat):
-  __slots__ = ('__inner', '__format')
+  __slots__ = ('__inner',)
 
   def __init__(self, json: dict, format: str):
     self.__inner = json
@@ -351,7 +351,7 @@ class CurrentForecast(BaseForecast):
         datetime: The local time.
     """    
 
-    return datetime(self._BaseForecast__inner['localObsDateTime'], '%Y-%m-%d %I:%M %p').astimezone(self.local_timezone)
+    return datetime.strptime(self._BaseForecast__inner['localObsDateTime'], '%Y-%m-%d %I:%M %p').astimezone(self.local_timezone)
 
   @property
   def utc_time(self) -> datetime:
@@ -376,7 +376,7 @@ class HourlyForecast(BaseForecast):
         str: The string representation of said object.
     """
 
-    return f'<HourlyForecast time={self.time!r} temperature={self.temperature!r} description={self.description!r} type=\'{self.type!r}\'>'
+    return f'<HourlyForecast time={self.time!r} temperature={self.temperature!r} description={self.description!r} type={self.type!r}>'
 
   @property
   def dew_point(self) -> int:
@@ -515,13 +515,18 @@ class HourlyForecast(BaseForecast):
     return int(self._BaseForecast__inner['cloudcover'])
 
   @property
-  def time(self) -> int:
+  def time(self) -> time:
     """
     Returns:
-        int: The minutes offset.
+        time: The time in hours and minutes.
     """
 
-    return int(self._BaseForecast__inner['time'])
+    try:
+      t = self._BaseForecast__inner['time']
+      
+      return time(int(t[:-2]), int(t[2:]))
+    except ValueError:
+      return time()
 
 class DailyForecast(ModifiableFormat):
   __slots__ = ('__inner',)
@@ -537,7 +542,7 @@ class DailyForecast(ModifiableFormat):
         str: The string representation of said object.
     """
 
-    return f'<DailyForecast date={self.date!r} astronomy={self.astronomy!r} temperature={self.temperature!r} description={self.description!r} type={self.type!r}>'
+    return f'<DailyForecast date={self.date!r} astronomy={self.astronomy!r} temperature={self.temperature!r}>'
 
   @property
   def astronomy(self) -> Astronomy:
@@ -577,7 +582,7 @@ class DailyForecast(ModifiableFormat):
     return int(self.__inner[f'maxtemp{self._ModifiableFormat__format}'])
   
   @property
-  def average_temperature(self) -> int:
+  def temperature(self) -> int:
     """
     Returns:
         int: The average temperature. In Celcius or Fahrenheit.
@@ -674,9 +679,9 @@ class Weather(ModifiableFormat):
     """
 
     try:
-      for req in filter(lambda x: x['type'] != 'LatLon', self.__inner['request']):
+      for req in filter(lambda x: x['type'] == 'LatLon', self.__inner['request']):
         lat, lon = LATLON_REGEX.findall(req['query'])[0]
 
-        return int(lat), int(lon)
+        return float(lat), float(lon)
     except:
-      pass
\ No newline at end of file
+      pass
